/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     effect.h

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/
#ifndef EFFECT_H_ 
#define EFFECT_H_

#include "common.h"
#include "task_control.h"

#ifdef __cplusplus
extern "C" {
#endif

// Macro constants
#ifdef SDK_TEG
#define TITLE_UP_POSITION       (FX32_ONE * 274)
#define TITLE_DOWN_POSITION     (FX32_ONE * 466)
#else
#define TITLE_UP_POSITION       (FX32_ONE * 82)
#define TITLE_DOWN_POSITION     (FX32_ONE * 274)
#endif
#define TITLE_MOVE_SPEED        (FX32_ONE * 3)
#define DISPLAY_PRIORITY_TITLE_MINI     255
#define DISPLAY_PRIORITY_SMOKE          100
#define DISPLAY_PRIORITY_PIPE             0

// Declaration of external functions
extern void StarBirth(void);
extern void Star_Init(void);
extern void Star(void);
extern void Title_Init(void);
extern void Title(void);
extern void TitleMini_Init(void);
extern void TitleMini(void);
extern void Pipe(void);
extern void Smoke_Init(void);
extern void Smoke(void);

// Declaration of external variables
extern ObjData objDataSmoke;
extern ObjData objDataPipe;
extern ObjData objDataTitle;
extern ObjData objDataTitleMini;
extern ObjData objDataStar;
extern const NitroCharacterData fileSmoke;
extern const NitroCharacterData filePipe;
extern const NitroCharacterData fileTitle;
extern const NitroCharacterData fileTitleMini;
extern const NitroCharacterData fileStar;
extern NNSG2dImageAttr TexAttrTitleMini;
extern NNSG2dImageAttr TexAttrTitle;
extern NNSG2dImageAttr TexAttrSmoke;
extern NNSG2dImageAttr TexAttrPipe;

// Effect-exclusive task structure
typedef struct EffectTask {
    
    /* Common */
    TaskCommonData common;
    
    /* Exclusive */
    NNSG2dFVec2     pos;                /* Cell XY coordinates */
    MtxFx22         mtxAffine;          /* Cell affine matrix */
    Direction       direction;          /* Direction */
    NNSG2dCellAnimation* cellAnim;      /* Pointer to the cell animation entity */ 
    NNSG2dFVec2     velocity;           /* Speed (right and up are positive)*/
    fx32            animSpeed;          /* Animation speed */
    u32             alpha;              /* Alpha value */             
    NNSG2dFVec2     size;               /* Size */
    u16             rotate;             /* Angle of rotation ( unit = 360 / 65535 ) */
    GXRgb           color;              /* Color */
    fx32            param1;             /* Free parameter 1 */
    fx32            param2;             /* Free parameter 2 */
 
} EffectTask;

#ifdef __cplusplus
}/* extern "C" */
#endif

#endif // EFFECT_H_
