/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     renderer.h

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/
#ifndef RENDERER_H_ 
#define RENDERER_H_

#define NUM_OF_CELLANM      1000               // The number of cell animations to display
#define NUM_OF_VRAMSTATE    NUM_OF_CELLANM     // The number of states the cell transmission manager handles
#define NUM_OF_VRAMTASK     NUM_OF_CELLANM     // The number of transmission tasks the VRAM transmission manager handles

#define SURFACE_MAIN_INIT_POS ((NNSG2dFVec2){0 << FX32_SHIFT, 0 << FX32_SHIFT})
#define SURFACE_SUB_INIT_POS ((NNSG2dFVec2){0 << FX32_SHIFT, SCREEN_HEIGHT << FX32_SHIFT})

#define NUM_OF_OAM       128                   // The number of OAMs to allocate to the OAM manager
#define NUM_OF_AFFINE    (NUM_OF_OAM / 4)      // The number of affine parameters to allocate to the OAM manager

/* OBJ size structure */
typedef struct ObjWH{   
    u8 width;
    u8 height;  
} ObjWH;

// Declaration of external variables
extern NNSG2dRendererInstance      render3D;      /* 3D Renderer  */
extern NNSG2dRendererInstance      render2D;      /* 2D Renderer  */
extern NNSG2dOamManagerInstance    sMainOamMan;   /* Callback handler target OAM manager */
extern NNSG2dOamManagerInstance    sSubOamMan;    /* Callback handler target OAM manager */
extern const ObjWH ObjShapeAndObjSizeTable[3][4]; /* OBJ size table */

// Declaration of internal functions
static inline u8 GetObjWidth(u32 shape, u32 size)
{
    return ObjShapeAndObjSizeTable[shape][size].width;
}

static inline u8 GetObjHeight(u32 shape, u32 size)
{
    return ObjShapeAndObjSizeTable[shape][size].height;
}

static inline u32 GetObjY(NNSG2dCellOAMAttrData* oam)
{
    return *(u32 *)oam & GX_OAM_ATTR01_Y_MASK;
}

static inline u32 GetObjX(NNSG2dCellOAMAttrData* oam)
{
    return (*(u32 *)oam & GX_OAM_ATTR01_X_MASK) >> GX_OAM_ATTR01_X_SHIFT;
}

// Declaration of external functions
extern void InitG2D(void);
extern void BeginRendering3D(void);
extern void EndRendering3D(void);
extern void BeginRendering2D(void);
extern void EndRendering2D(void);


#endif // RENDERER_H_


