/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     task_control.h

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/
#ifndef TASK_CONTROL_H_ 
#define TASK_CONTROL_H_

#include <nitro.h>
#include <nnsys/g2d/g2d_Softsprite.h>
#include <nnsys/g2d/g2d_CellAnimation.h>

#ifdef __cplusplus
extern "C" {
#endif
 
#define  TASK_CTRL_AREA_NUM  1000   /* Number of tasks */

#define TASK_NUMBER_HEAD  0         /* Starting task number */
#define TASK_NUMBER_TAIL  1         /* Ending task number */

typedef void (*Funcp)();

// Direction list designator
typedef enum Direction 
{
    LEFT, 
    RIGHT, 
    UP, 
    DOWN
} Direction;

// Damage structure
typedef struct Damage {
    s32 value;
    Direction direction;
} Damage;

typedef struct Task Task;

// Task common structure
typedef struct TaskCommonData {
    Funcp func;                 /* Execution function */
    Task* prev;                 /* Previous task */
    Task* next;                 /* Next task */
    BOOL  reqReleaseFlag;       /* Release request flag */
    Funcp releaseFunc;          /* Deallocation function */  
    u16   priority;             /* Priority */
    u16   pad;                  /* Padding */
} TaskCommonData;

// Task structure
struct Task{
    /* Common */
    TaskCommonData common;
    /* Reserved region */      
    u8 reserve[128];           
};

// Declaration of functions
void TaskCtrl_Init(void);
Task* TaskCtrl_SetTask(Funcp func, u16 priority);
void OperateNothing(void);
void TaskCtrl_ExecuteAllTasks(void);
void TaskCtrl_SetReleaseFlagAll(void);
void TaskCtrl_SetReleaseFlagRange(u16 minimum, u16 maximum);
void TaskCtrl_SetReleaseFlagAllWithMask(u16 mask[], u16 num);
void TaskCtrl_SetReleaseFlagByPriority(u16 priority);
Task* TaskCtrl_GetCurrentTask(void);
Task* TaskCtrl_GetHeadTask(void);

#ifdef __cplusplus
}/* extern "C" */
#endif

#endif // TASK_CTRL_H_
