/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     utility.h

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/
#ifndef UTILITY_H_ 
#define UTILITY_H_

#include <nitro.h>
#include <nnsys/g2d.h>
#include <nnsys/fnd.h>
#include "common.h"
#include "task_control.h"
 
#ifdef __cplusplus
extern "C" {
#endif
 
#define   COLOR_RED    0x001F
#define   COLOR_GREEN  0x03E0
#define   COLOR_BLUE   0x7C00
#define   COLOR_WHITE  0x7FFF
#define   COLOR_BLACK  0x0000
#define   CELL_ANIM_ARRAY_SIZE  1000

// Declaration of functions
void UT_InitCellAnimStack(void);
NNSG2dCellAnimation* UT_GetCellAnimation(void);
void UT_ReleaseCellAnimation(NNSG2dCellAnimation* anim);
void* UT_LoadNCER( NNSG2dCellDataBank** ppCellBank, const char* pFname );
void* UT_LoadNANR( NNSG2dAnimBankData** ppAnimBank, const char* pFname );
void* UT_LoadNMCR( NNSG2dMultiCellDataBank** ppMCBank, const char* pFname );
void* UT_LoadNMAR( NNSG2dMultiCellAnimBankData** ppMCABank, const char* pFname );
void* UT_LoadNCGR( NNSG2dCharacterData** ppCharData, const char* pFname );
void* UT_LoadNCLR( NNSG2dPaletteData** ppPltData, const char* pFname );
void* UT_LoadNENR( NNSG2dEntityDataBank** ppEntityBank, const char* pFname );
void* UT_LoadNCBR( NNSG2dCharacterData** ppCharData, const char* pFname );

static inline void G2T_MTX_Rot22( MtxFx22* m, fx32 sinVal, fx32 cosVal )
{
    SDK_NULL_ASSERT( m );
    m->_00 = cosVal;
    m->_01 = sinVal;
    m->_10 = -sinVal;
    m->_11 = cosVal;
}

void UT_SetUpNitroCharacterData3D(
    ObjData* objData, 
    const NitroCharacterData* nitroCharData,
    u32 texBaseAddr,
    u32 plttBaseAddr
);

void UT_SetUpNitroCharacterData2D(
    ObjData* objData, 
    const NitroCharacterData* nitroCharData,
    u32 charBaseAddr,
    u32 plttBaseAddr
);

inline void* UT_Alloc(u32 size)
{
    SDK_ASSERT( size > 0 );
    return NNS_FndAllocFromExpHeap(gHeapHandle, size);
}

inline void UT_Free(void* memBlock)
{
    SDK_ASSERT( NNS_FndFindContainHeap(memBlock) == gHeapHandle );
    NNS_FndFreeToExpHeap(gHeapHandle, memBlock);
}

inline fx32 FX_ABS(fx32 x) { return x>=0 ? x : -x; }

#ifdef __cplusplus
}/* extern "C" */
#endif

#endif // UTILITY_H_
