/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     yoshi.h

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/
#ifndef YOSHI_H_ 
#define YOSHI_H_

#include <nitro.h>
#include "common.h"
#include "task_control.h"

#ifdef __cplusplus
extern "C" {
#endif

// Definition of macro constants

/* Actually 24, but in order to match the ground to the height of the feet, take 8 away */
#define YOSHI_HEIGHT_HALF (FX32_ONE * 16)   
/* Boundary line where either Yoshi or the BG is moved up and down */
#define YOSHI_UPDOWN_BORDER  (FX32_ONE * 112)

typedef enum AttackSuccess
{
    ATTACK_NONE,
    ATTACK_STEP_ON,     // Attack by stepping on
    ATTACK_SWALLOW      // Attack by swallowing
} AttackSuccess;

#define YOSHI_ANIM_STAY        0
#define YOSHI_ANIM_WALK        1
#define YOSHI_ANIM_AIR_WALK    1
#define YOSHI_ANIM_JUMP_UP     2
#define YOSHI_ANIM_JUMP_DOWN   3
#define YOSHI_ANIM_FRONT_TURN  4
#define YOSHI_ANIM_BRAKE       5

// Yoshi exclusive task structure
#pragma  warn_padding off
typedef struct YoshiTask {
    
    /* Common */
    TaskCommonData common;

    /* Exclusive */
    NNSG2dFVec2     pos;                /* Cell XY coordinates */
    MtxFx22         mtxAffine;          /* Cell affine matrix */
    Direction       direction;          /* Direction */
    NNSG2dFVec2     velocity;           /* Speed (Right and up are positive)*/
    fx32            animSpeed;          /* Animation speed */
    u32             alpha;              /* Alpha value */             
    NNSG2dSVec2     size;               /* Size */
    NNSG2dCellAnimation* cellAnim;      /* Pointer to the cell animation entity */  
    u32             cellTransManHandle; /* Handle of the cell transmission state manager object */
    Damage          damage;             /* Damage */ 
    AttackSuccess   attackSuccess;      /* Attack success */
    s16             hitpoint;           /* Hit points */
    s16             spirit;             /* Spirit */
    s16             injuryTime;         /* Injury interval */
    
} YoshiTask;
#pragma  warn_padding reset

// Declaration of external variables
extern const NNSG2dImageAttr yoshiTexAttr;
extern ObjData objDataYoshi;
extern const NitroCharacterData fileYoshi;

// Declaration of external functions
extern void YoshiBirth(void);
extern void YoshiFree(YoshiTask* task);
extern void YoshiStay_Init(void);
extern void YoshiStay(void);
extern void YoshiBrake_Init(void);
extern void YoshiBrake(void);
extern void YoshiWalk_Init(void);
extern void YoshiWalk(void);
extern void YoshiAirWalk_Init(void);
extern void YoshiAirWalk(void);
extern void YoshiFrontTurn_Init(void);
extern void YoshiFrontTurn(void);
extern void YoshiJumpUp_Init(void);
extern void YoshiJumpUp(void);
extern void YoshiJumpDown_Init(void);
extern void YoshiJumpDown(void);
extern void MoveX_WithGroundCheckYoshi(YoshiTask* task);
extern void MoveY_WithGroundCheckYoshi(YoshiTask* task);
extern void DrawYoshi(void);

#ifdef __cplusplus
}/* extern "C" */
#endif

#endif // YOSHI_H_
