/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     background01.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include "task_control.h"
#include "background.h"
#include "common.h"

// Definition of internal variables
static s32 sHOffsetBg1;
static s32 sVOffsetBg1;

/*---------------------------------------------------------------------------*
  Name:         BackGround01

  Description:  Displays the background (BG1).
                Scrolls up, down, right, and left to match Yoshi's movements.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void BackGround01(void)
{
    s32 left_pos = gBgHScroll;
    u32 mapR;
    u32 mapL;
    u32 lineR;
    u32 lineL;
    u16 i;

    sHOffsetBg1 = gBgHScroll;
    sVOffsetBg1 = 64 + gBgVScroll;  // 64 is the initial movement value (256-192)

    if (left_pos < 0)               // Also corresponds to negative coordinates
    {
        left_pos %= STAGE_LENGTH;   // 2048 dots is one cycle
        left_pos += STAGE_LENGTH;
    }
    
    // Manage by splitting up into screens 0-7 from the left
    mapR  = ((left_pos+256+8)/256) & 7U;     // Overwrite the applicable screen data in the display screen's left edge + 256 + 8 dot row.
                                            // In order to do so, request the screen to reference.
    lineR = ((left_pos/8)+1)&31U;            // Looks for the re-write line (0 - 31)

    mapL  = ((left_pos+2040)/256) & 7U;
    lineL = ((left_pos/8)+31)&31U;

    for (i=0;i<32;i++)
    {
        fieldScrnBuf[mapR&1][i][lineR] = fieldScreen[mapR][i][lineR];   //  screen data update (right side)
        fieldScrnBuf[mapL&1][i][lineL] = fieldScreen[mapL][i][lineL];   //  screen data update (left side)
    }           
    DC_FlushRange(fieldScrnBuf, sizeof(fieldScrnBuf));        
}

/*---------------------------------------------------------------------------*
  Name:         UpdateBg1ScreenOffset

  Description:  Updates the background (BG1) screen offset.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void UpdateBg1ScreenOffset(void)
{
    G2_SetBG1Offset(sHOffsetBg1, sVOffsetBg1);  
}

/*---------------------------------------------------------------------------*
  Name:         UpdateBg1ScreenData

  Description:  Updates the background (BG1) screen data.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void UpdateBg1ScreenData(void)
{
    GX_LoadBG1Scr(fieldScrnBuf, 0, sizeof(fieldScrnBuf));
}

