/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     background02.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include "task_control.h"
#include "background.h"
#include "common.h"

// Definition of variables
static s32 sHOffsetBg2;
static s32 sVOffsetBg2;

/*---------------------------------------------------------------------------*
  Name:         BackGround02

  Description:  Displays the background (BG2).
                Scrolls up, down, right, and left according to Yoshi's movements.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void BackGround02(void)
{
    u32  srcMapR;
    u32  dstMapR;
    u32  srcMapL;
    u32  dstMapL;
    u32 dstLineR;
    u32 dstLineL;
    u32 srcLineR;
    u32 srcLineL;
    u16 i;

    sHOffsetBg2 = gBgHScroll  >> BG2_H_SCROLL_SPEED_SHIFT;
    sVOffsetBg2 = U32_SCREEN_CENTER_X + gBgVScroll >> BG2_V_SCROLL_SPEED_SHIFT;   // U32_SCREEN_CENTER_X is the initial value

    // The screen data is a 512-dot (64-line) period
    dstLineR = (sHOffsetBg2/8 + 33) & 63U;               // Overwrite the 33rd line from the left edge of the screen
    dstLineL = (sHOffsetBg2/8 + 63) & 63U;               // Overwrite the right 33rd line from the left edge of the screen
        
    // 360-dot (45-line) period of the mountain picture
    srcLineR = (((sHOffsetBg2%360)/8) + 33 + 45) % 45U;  // The 33rd line right from the left side of the screen is the source
    srcLineL = (((sHOffsetBg2%360)/8) + 44 + 45) % 45U;  // The 44th line right from the left side of the screen is the source

    srcMapR = (srcLineR < 32) ? 0 : 1U;
    dstMapR = (dstLineR < 32) ? 0 : 1U;
    srcMapL = (srcLineL < 32) ? 0 : 1U;
    dstMapL = (dstLineL < 32) ? 0 : 1U;
        
    dstLineR = dstLineR & 31U;
    srcLineR = srcLineR & 31U;

    dstLineL = dstLineL & 31U;
    srcLineL = srcLineL & 31U;

    for (i=0;i<32;i++)
    {
        mountScrnBuf[dstMapR][i][dstLineR] = mountScreen[srcMapR][i][srcLineR];
        mountScrnBuf[dstMapL][i][dstLineL] = mountScreen[srcMapL][i][srcLineL];
    }
}

/*---------------------------------------------------------------------------*
  Name:         UpdateBg2ScreenOffset

  Description:  Updates the screen offset of the background (BG2).
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void UpdateBg2ScreenOffset(void)
{
    G2_SetBG2Offset(sHOffsetBg2, sVOffsetBg2);
}

/*---------------------------------------------------------------------------*
  Name:         UpdateBg2ScreenData

  Description:  Updates the screen data of the background (BG2).
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void UpdateBg2ScreenData(void)
{
    GX_LoadBG2Scr(mountScrnBuf, 0, sizeof(mountScrnBuf));      
}

