/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     check_collision.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include "task_control.h"
#include "task_priority.h"
#include "utility.h"
#include "yoshi.h"
#include "enemy.h"

// Declaration of functions
void CheckCollision(void);

// Declaration of internal functions
static void CheckCollisionWithEnemy(YoshiTask *pYoshi);
static void CheckCollisionTwo(YoshiTask *pYoshi, EnemyTask *pEnemy);

/*---------------------------------------------------------------------------*
  Name:         CheckCollision

  Description:  Determines whether or not Yoshi and the enemy have collided.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/


void CheckCollision(void)
{
    YoshiTask  *pYoshi = (YoshiTask *)TaskCtrl_GetHeadTask()->common.next;

    while(1)
    {
        if (pYoshi->common.priority == TASK_PRIORITY_YOSHI)
        {
            CheckCollisionWithEnemy(pYoshi);
        }
        else if (pYoshi->common.priority > TASK_PRIORITY_YOSHI)
        {
            break;
        }
        pYoshi = (YoshiTask *)pYoshi->common.next;
    }   
}


static void CheckCollisionWithEnemy(YoshiTask *pYoshi)
{
    EnemyTask  *pEnemy = (EnemyTask *)pYoshi->common.next;
    
    while(1)
    {
        if (pEnemy->common.priority == TASK_PRIORITY_ENEMY || 
        	pEnemy->common.priority == TASK_PRIORITY_ENEMY_NOTRENDER)
        {
            CheckCollisionTwo(pYoshi, pEnemy);
        }
        else if (pEnemy->common.priority > TASK_PRIORITY_ENEMY_NOTRENDER)
        {
            break;
        }
        pEnemy = (EnemyTask *)pEnemy->common.next;
    }
}


static void CheckCollisionTwo(YoshiTask *pYoshi, EnemyTask *pEnemy)
{
    fx32 diff = FX_ABS(pYoshi->pos.x - pEnemy->pos.x);
    fx32 width;
    fx32 yoshiWidth  = FX_Mul(FX32_ONE * 32, pYoshi->size.x);
    fx32 yoshiHeight = FX_Mul(FX32_ONE * 32, pYoshi->size.y);
    fx32 enemyWidth  = FX_Mul(FX32_ONE * 32, pEnemy->size.x);
    fx32 enemyTop    = pEnemy->pos.y - FX_Mul(FX32_ONE * 32, pEnemy->size.y) + FX32_ONE * 8;    // 8 is the difference between size.y and the actual display size

    // Do not display while damaged
    if (pYoshi->injuryTime > 0)
    {
        return;
    }
    
    // If the enemy is dead, do not perform a collision check
    if (pEnemy->hitpoint == 0)
    {
        return;
    }
    
    // Look for the width of the character in the left position as the width.
    if ((pYoshi->pos.x - pEnemy->pos.x) < 0)        
    {                                               
        width = yoshiWidth - FX32_ONE * 8;  // 8 is the difference from the actual display
    }
    else                                            
    {                                               
        width = enemyWidth - FX32_ONE * 8;  // 8 is the difference from the actual display
    }
    
    if (diff < width)                       // Piled up in the vertical direction
    {   
        if (pYoshi->pos.y > enemyTop)       // If Yoshi's foot is lower than the enemy's head
        {
            if (pYoshi->pos.y < (enemyTop + FX32_ONE * 8))              // Yoshi has stepped on the enemy's head
            {
                pYoshi->attackSuccess = ATTACK_STEP_ON;
                pEnemy->hitpoint =  0;          
            }
            else if ((pYoshi->pos.y - yoshiHeight) < pEnemy->pos.y)     // Yoshi has come into contact with the enemy's body
            {
                pYoshi->injuryTime = 100;
            }
        }
    }
}

