/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     fade.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include "task_control.h"
#include "fade.h"

// Definition of internal variables
static s8 sBrightness = -16;    /* Master brightness */

/*---------------------------------------------------------------------------*
  Name:         GetBrightness

  Description:  Returns the current brightness value.
                        
  Arguments:    None
                
  Returns:      The current master brightness value
 *---------------------------------------------------------------------------*/

s8 GetBrightness(void)
{
    return sBrightness;
}

/*---------------------------------------------------------------------------*
  Name:         FadeIn

  Description:  Performs a fade-in.
                The task will be deallocated once the fade-in finishes.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void FadeIn(void)
{
    Task* pSelfTask = (Task *)TaskCtrl_GetCurrentTask();

    GX_SetMasterBrightness(++sBrightness);

    if (sBrightness == 0)
    {
        pSelfTask->common.reqReleaseFlag = TRUE;
    }
}

/*---------------------------------------------------------------------------*
  Name:         FadeOut

  Description:  Performs a fade-out.
                        
  Arguments:    None
                
  Returns:      The current master brightness value
 *---------------------------------------------------------------------------*/

s8 FadeOut(void)
{
    if (sBrightness > -16)
    {
        sBrightness--;
    }
    GX_SetMasterBrightness(sBrightness);
    return sBrightness;
}



