/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     geography.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/ 

#include <nitro.h>
#include <nnsys/g2d.h>
#include "common.h"

// Declaration of functions
fx32 GetGeographicHeight(fx32 x);

static const NNSG2dFVec2 geographyJudgePoint[] =
{
    {FX32_ONE * 0  , FX32_ONE * 48},
    {FX32_ONE * 304, FX32_ONE * 48},
    {FX32_ONE * 368, FX32_ONE * 80},
    {FX32_ONE * 480, FX32_ONE * 80},
    {FX32_ONE * 480, FX32_ONE * 96},
    {FX32_ONE * 544, FX32_ONE * 96},    
    {FX32_ONE * 544, FX32_ONE * 144},   
    {FX32_ONE * 704, FX32_ONE * 144},   
    {FX32_ONE * 704, FX32_ONE * 0}, 
    {FX32_ONE * 768, FX32_ONE * 0}, 
    {FX32_ONE * 768, FX32_ONE * 144},   
    {FX32_ONE * 880, FX32_ONE * 144},   
    {FX32_ONE * 1080, FX32_ONE * 48},   
    {FX32_ONE * 1120, FX32_ONE * 48},   // Pipe lower left 
    {FX32_ONE * 1120, FX32_ONE * 77},   // Pipe upper left 
    {FX32_ONE * 1160, FX32_ONE * 77},   // Pipe upper right
    {FX32_ONE * 1160, FX32_ONE * 48},   // Pipe lower right
    {FX32_ONE * 1200, FX32_ONE * 48},   
    {FX32_ONE * 1328, FX32_ONE * 112},  
    {FX32_ONE * 1456, FX32_ONE * 112},  
    {FX32_ONE * 1456, FX32_ONE * 64},   
    {FX32_ONE * 1584, FX32_ONE * 64},   
    {FX32_ONE * 1584, FX32_ONE * 0},    
    {FX32_ONE * 1680, FX32_ONE * 0},    
    {FX32_ONE * 1680, FX32_ONE * 80},   
    {FX32_ONE * 1808, FX32_ONE * 80},   
    {FX32_ONE * 1808, FX32_ONE * 48},   
    {FX32_ONE * 2048, FX32_ONE * 48}
};

/*---------------------------------------------------------------------------*
  Name:         GetGeographicHeight

  Description:  Returns the height of the geography.
                Returns the upper edge of the screen as a 0 value.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

fx32 GetGeographicHeight(fx32 x)
{   
    u32 area = 0;
    fx32 inclination;   /* inclination */
    fx32 height;
        
    // Negative value is offset
    x = FX_Mod(x, FX32_ONE * STAGE_LENGTH); /* The stage is a 2048-dot period */
    if (x < 0)
    {
        x += FX32_ONE * STAGE_LENGTH;
    }
    
    // Determine area
    while(1)
    {
        if (x < geographyJudgePoint[++area].x) 
        {
            break;
        }
    }

    // Calculation of 2-point inclination
    inclination = FX_Div((geographyJudgePoint[area].y - geographyJudgePoint[area-1].y), 
                         (geographyJudgePoint[area].x - geographyJudgePoint[area-1].x)); 
    
    height = FX_Mul(inclination, x - geographyJudgePoint[area-1].x) + geographyJudgePoint[area-1].y;
    height = FX32_ONE * 192 - height;   // Convert to the height counted from the top of the screen
    
    return height;
}
