/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     heiho_red_birth.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include <nnsys/g2d.h>
#include "utility.h"
#include "enemy.h"
#include "vram_map.h"

// Declaration of internal functions
static void HeihoRedFree(EnemyTask* task);

/*---------------------------------------------------------------------------*
  Name:         HeihoRedBirth

  Description:  Execute when generating the Heiho task.
                Changes the task to [HeihoRedWalk_Init]
                after initialization.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void HeihoRedBirth(void)
{
    EnemyTask* pSelfTask = (EnemyTask *)TaskCtrl_GetCurrentTask();

    pSelfTask->hitpoint  = 1;
    pSelfTask->animSpeed = FX32_ONE;
    pSelfTask->direction = (pSelfTask->velocity.x > 0) ? RIGHT : LEFT ;     
    pSelfTask->common.releaseFunc = HeihoRedFree;

    // Initialize the cell animation entity
    {                    
        pSelfTask->cellAnim = UT_GetCellAnimation();    // Get an empty NNSG2dCellAnimation
                                                        // Deallocate when task screen
        SDK_NULL_ASSERT( pSelfTask->cellAnim );
        SDK_ASSERT( objDataHeihoRed.pAnimBank->numSequences != 0 );
        SDK_NULL_ASSERT( &objDataHeihoRed.pAnimBank->pSequenceArrayHead[0] );
        NNS_G2dInitCellAnimation( 
                    pSelfTask->cellAnim,                                
                    &objDataHeihoRed.pAnimBank->pSequenceArrayHead[0],  
                    objDataHeihoRed.pCellBank );                        
    }
    
    pSelfTask->common.func = HeihoRedWalk_Init;        // Change task to [HeihoRedWalk_Init]
}

/*---------------------------------------------------------------------------*
  Name:         HeihoFree

  Description:  Deallocates the region allocated by HeihoBirth.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

static void HeihoRedFree(EnemyTask* task)
{
    // Deallocates the cell animation
    UT_ReleaseCellAnimation(task->cellAnim);
}

