/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     heiho_red_die.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include <nnsys/g2d.h>
#include "read_key.h"
#include "task_control.h"
#include "vram_map.h"
#include "enemy.h"
#include "renderer.h"

/*---------------------------------------------------------------------------*
  Name:         HeihoRedDie

  Description:  After the death displays, deallocates the task.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void HeihoRedDie(void)
{
    EnemyTask* pSelfTask = (EnemyTask *)TaskCtrl_GetCurrentTask();
    u16          rotate  = 0;   // Angle of rotation
    NNSG2dFVec2  scale;         // Scale
    NNSG2dFVec2  pos;           // Cell render position
        
    scale.x = pSelfTask->size.x;
    scale.y = pSelfTask->size.y;

    // Flip substitution
    if (pSelfTask->direction == RIGHT)
    {
        scale.x *= -1;
    }
        
    // Calculation of display X coordinate (If the difference between this coordinate and Yoshi is 0, then that is the center of the screen)
    pos.x = FX32_SCREEN_CENTER_X + pSelfTask->pos.x - gYoshiPos.x; 
        
    // Calculation of the display Y value (FX32_ONE * 14 is the distance from the middle of Heiho to its feet)
    pos.y = pSelfTask->pos.y - FX_Mul(FX32_ONE * 14, pSelfTask->size.y) - FX32_ONE * gBgVScroll;
        
    // Material configuration
    MaterialSetup();
        
    // Render
    //
    // Render the cell using the Renderer module
    //
    {
        // Configure the image data and palette data that the renderer references.
        NNS_G2dSetRendererImageProxy( &render3D, &objDataHeihoRed.imageProxy, &objDataHeihoRed.paletteProxy );
        NNS_G2dPushMtx();
            NNS_G2dTranslate( pos.x, pos.y, 0 );
            NNS_G2dRotZ( FX_SinIdx( rotate ), FX_CosIdx( rotate ) );
            NNS_G2dScale( scale.x, scale.y, FX32_ONE );
            NNS_G2dDrawCellAnimation( pSelfTask->cellAnim );
        NNS_G2dPopMtx();
    }               

    // Deallocate if the height is smaller than the fixed size
    pSelfTask->size.y *= 0.9;
    if (pSelfTask->size.y < 100)
    {
        pSelfTask->common.reqReleaseFlag = TRUE;           
    }
}

