/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     heiho_red_emitter.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include <nnsys/g2d.h>
#include "task_priority.h"
#include "read_key.h"
#include "utility.h"
#include "enemy.h"
#include "emitter.h"

/*---------------------------------------------------------------------------*
  Name:         HeihoRedEmitter

  Description:  Generates a large number of Heihos.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void HeihoRedEmitter(void)
{
    EmitterTask* pSelfTask   = (EmitterTask *)TaskCtrl_GetCurrentTask();
    EnemyTask* enemy;
    fx16 rand;

    // Generate a Heiho once every four frames
    if (pSelfTask->counter++ > 3)
    {
        rand = FX_SinIdx(pSelfTask->rotate);
        
        pSelfTask->counter = 0;
        enemy = (EnemyTask *)TaskCtrl_SetTask(HeihoRedBirth, TASK_PRIORITY_ENEMY); 
        enemy->velocity.x = rand;
        enemy->velocity.y = FX32_ONE * 5 + rand;
        enemy->pos.x = pSelfTask->pos.x;
        enemy->pos.y = FX32_ONE * 118;
        enemy->size.x = FX32_HALF;
        enemy->size.y = FX32_HALF;

        // Deallocate the task once a set number of Heihos has been generated
        if (--pSelfTask->num == 0)
        {
            pSelfTask->common.reqReleaseFlag = TRUE;
        }
        
        pSelfTask->rotate += 20000;
    }
}


