/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     Killer.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include "utility.h"
#include <nnsys/g2d.h>  
#include "task_control.h"
#include "vram_map.h"
#include "enemy.h"

/*---------------------------------------------------------------------------*
  Name:         Killer

  Description:  Displays the killer.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void Killer(void)
{
    fx32 diff;
    EnemyTask* pSelfTask = (EnemyTask *)TaskCtrl_GetCurrentTask();
    NNSG2dExtendedSprite      spriteKiller;

    if (pSelfTask->hitpoint == 0)
    {
        pSelfTask->velocity.y += 400;   
    }

    pSelfTask->pos.x += pSelfTask->velocity.x;  // X movement
    pSelfTask->pos.y += pSelfTask->velocity.y;  // Y movement
    
    spriteKiller.uvUL.x = 0;
    spriteKiller.uvLR.x = FX32_ONE * 32;
    spriteKiller.uvUL.y = 0;
    spriteKiller.uvLR.y = FX32_ONE * 32;
    spriteKiller.basicParams.color = GX_RGB( 31, 31, 31 );

    spriteKiller.flipH = FALSE;
    spriteKiller.flipV = FALSE;
    
    spriteKiller.rotO.x = 0;
    spriteKiller.rotO.y = 0;
    spriteKiller.rotX = 0;
    spriteKiller.rotY = 0;
    
    spriteKiller.basicParams.pTextureAttr = &TexAttrKiller;
    spriteKiller.basicParams.texAddr      = VRAM_MAP_TEX_KILLER;
    spriteKiller.basicParams.plttAddr     = VRAM_MAP_TEXPLTT_KILLER;
    spriteKiller.basicParams.plttOffset   = 0;
    
    diff = pSelfTask->pos.x - gYoshiPos.x; 
    spriteKiller.basicParams.simpleParams.pos.x     = (s16)(129 + (diff >> FX32_SHIFT) - (pSelfTask->size.x * 32 >> (FX32_SHIFT + 1)));
    spriteKiller.basicParams.simpleParams.pos.y     = (s16)(((pSelfTask->pos.y - FX_Mul(FX32_ONE * 32, pSelfTask->size.y)) >>FX32_SHIFT) - gBgVScroll);
    spriteKiller.basicParams.simpleParams.priority  = 0;
    spriteKiller.basicParams.simpleParams.size.x    = 32;
    spriteKiller.basicParams.simpleParams.size.y    = 32;
    spriteKiller.basicParams.simpleParams.rotZ      = 0;
    spriteKiller.basicParams.simpleParams.alpha     = 31;

    // Do Draw
    NNS_G2dDrawSpriteExtended( &spriteKiller );

    // Deallocate the task if separated a fixed distance from Yoshi, or if disappeared at the bottom of the screen.
    if (FX_ABS(pSelfTask->pos.x - gYoshiPos.x) > FX32_ONE * 512 ||
        pSelfTask->pos.y > FX32_ONE * 255)
    {
        pSelfTask->common.reqReleaseFlag = TRUE;           
    }
}


