/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     main.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include <nnsys/g2d.h>
#include "task_priority.h"
#include "common.h"
#include "utility.h"
#include "read_key.h"
#include "background.h"
#include "yoshi.h"
#include "scene.h"

// Declaration of functions
void VBlankIntr(void);

/*---------------------------------------------------------------------------*
  Name:         NitroMain

  Description:  The starting point of the user program.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void NitroMain()
{
    // Performs system- and render-related initialization.
    CommonInit();

    // Start title scene
    (void)TaskCtrl_SetTask(SceneTitle_Init, TASK_PRIORITY_SCENE);

    // Main loop   
    while( TRUE )
    {  
        if (IS_TRIG(PAD_BUTTON_X))                  // Dumps the main memory usage conditions
        {
            NNS_FndDumpHeap(gHeapHandle);
        }
                
        *(GXRgb*)(HW_DB_BG_PLTT)    = COLOR_BLUE;   // simple burden measurement with the backdrop color
        TaskCtrl_ExecuteAllTasks();                 // Execute all tasks
        *(GXRgb*)(HW_DB_BG_PLTT)    = COLOR_BLACK;  //         
    
        // Send the transmission request to the cell transmission manager to the
        // VRAM transmission manager via a callback function
        NNS_G2dUpdateCellTransferStateManager();

        G3_SwapBuffers(GX_SORTMODE_AUTO, GX_BUFFERMODE_Z);

        // V-Blank wait
        SVC_WaitVBlankIntr();

        // Perform VRAM transmission
        NNS_GfdDoVramTransfer();      
        
        // Update the BG screen offset
        UpdateBg1ScreenOffset();
        UpdateBg2ScreenOffset();
        UpdateBg3ScreenOffset();

        // Update the BG screen data
        UpdateBg1ScreenData();
        UpdateBg2ScreenData();
    }
}

/*---------------------------------------------------------------------------*
  Name:         VBlankIntr

  Description:  The V-Blank interrupt process.
                Updates the VRAM data.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void VBlankIntr(void)
{
    OS_SetIrqCheckFlag( OS_IE_V_BLANK );
}

