/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     pipe.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include <nnsys/g2d.h>  
#include "utility.h"
#include "task_control.h"
#include "vram_map.h"
#include "effect.h"
#include "yoshi.h"

/*---------------------------------------------------------------------------*
  Name:         Pipe

  Description:  Displays a pipe
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void Pipe(void)
{
    fx32 parent_pos_x;
    fx32 diff;
    EffectTask* pSelfTask = (EffectTask *)TaskCtrl_GetCurrentTask();
    NNSG2dExtendedSprite      spritePipe;

    spritePipe.uvUL.x = 0;
    spritePipe.uvLR.x = FX32_ONE * 32;
    spritePipe.uvUL.y = 0;
    spritePipe.uvLR.y = FX32_ONE * 32;
    spritePipe.basicParams.color = GX_RGB( 31, 31, 31 );

    spritePipe.flipH = FALSE;
    spritePipe.flipV = FALSE;
    
    spritePipe.rotO.x = 0;
    spritePipe.rotO.y = 0;
    spritePipe.rotX = 0;
    spritePipe.rotY = 0;
    
    spritePipe.basicParams.pTextureAttr = &TexAttrPipe;
    spritePipe.basicParams.texAddr      = VRAM_MAP_TEX_PIPE;
    spritePipe.basicParams.plttAddr     = VRAM_MAP_TEXPLTT_PIPE;
    spritePipe.basicParams.plttOffset   = 0;
    
    parent_pos_x = FX_Mod(gYoshiPos.x, FX32_ONE * STAGE_LENGTH);
    if (parent_pos_x < 0)
    {
        parent_pos_x += FX32_ONE * STAGE_LENGTH;
    }
    
    diff = pSelfTask->pos.x - parent_pos_x;
    spritePipe.basicParams.simpleParams.pos.x     = (s16)(U32_SCREEN_CENTER_X + (diff >> FX32_SHIFT) - (pSelfTask->size.x >> (FX32_SHIFT + 1)));
    spritePipe.basicParams.simpleParams.pos.y     = (s16)((pSelfTask->pos.y>>FX32_SHIFT) - gBgVScroll);
    spritePipe.basicParams.simpleParams.priority  = 0;
    spritePipe.basicParams.simpleParams.size.x    = (s16)(pSelfTask->size.x >> FX32_SHIFT); 
    spritePipe.basicParams.simpleParams.size.y    = (s16)(pSelfTask->size.y >> FX32_SHIFT); 
    spritePipe.basicParams.simpleParams.rotZ      = pSelfTask->rotate;
    spritePipe.basicParams.simpleParams.priority  = DISPLAY_PRIORITY_PIPE;
    spritePipe.basicParams.simpleParams.alpha     = 31;

    // Do Draw
    NNS_G2dDrawSpriteExtended( &spritePipe );
}


