/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     scene_change.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include "task_control.h"
#include "task_priority.h"
#include "scene.h"
#include "fade.h"

/*---------------------------------------------------------------------------*
  Name:         SceneChange

  Description:  Performs a scene change.
                A new scene is generated after the fadeout sequence ends and all
                task deallocation request flags are active.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void SceneChange(void)
{
    SceneTask* pSelfTask = (SceneTask *)TaskCtrl_GetCurrentTask();
    SceneTask* pNextTask;
    u16 mask[1];
    
    if (FadeOut() == MASTER_BRIGHTNESS_BLACK)
    {
        mask[0] = TASK_PRIORITY_TITLE;              // Does not deallocate the title logo display stack
        TaskCtrl_SetReleaseFlagAllWithMask(mask, 1);// Sets deallocation flags in all other stacks
        
        if (pSelfTask->nextScene != NULL)
        {
            // Sets the next scene
            pNextTask = (SceneTask *)TaskCtrl_SetTask(pSelfTask->nextScene, TASK_PRIORITY_SCENE);
            pNextTask->relateTask = pSelfTask->relateTask;  // Continues related tasks
        }
    }
}
