/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     smoke.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include <nnsys/g2d.h>  
#include "task_control.h"
#include "vram_map.h"
#include "effect.h"

/*---------------------------------------------------------------------------*
  Name:         Smoke

  Description:  Displays the smoke texture.
                Gradually become transparent. When completely transparent, the task is deallocated.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void Smoke(void)
{
    EffectTask* pSelfTask = (EffectTask *)TaskCtrl_GetCurrentTask();
    static u16      rotate = 0;     // Angle of rotation
    NNSG2dExtendedSprite  spriteSmoke;
    fx32 diff;
            
    G3X_AlphaBlend( TRUE );
                        
    spriteSmoke.uvUL.x = 0;
    spriteSmoke.uvLR.x = FX32_ONE * 32;
    spriteSmoke.uvUL.y = 0;
    spriteSmoke.uvLR.y = FX32_ONE * 32;
    spriteSmoke.basicParams.color = GX_RGB( 31, 31, 31 );

    spriteSmoke.flipH = FALSE;
    spriteSmoke.flipV = FALSE;
    
    spriteSmoke.rotO.x = 0;
    spriteSmoke.rotO.y = 0;
    spriteSmoke.rotX = rotate;
    spriteSmoke.rotY = 0;
    
    spriteSmoke.basicParams.pTextureAttr = &TexAttrSmoke;
    spriteSmoke.basicParams.texAddr      = VRAM_MAP_TEX_SMOKE;
    spriteSmoke.basicParams.plttAddr     = VRAM_MAP_TEXPLTT_SMOKE;
    spriteSmoke.basicParams.plttOffset   = 0;
    
    diff = pSelfTask->pos.x - gYoshiPos.x;      // Difference between the current position of Yoshi and the smoke
    spriteSmoke.basicParams.simpleParams.pos.x     = (s16)(129 + (diff >> FX32_SHIFT) - (pSelfTask->size.x >> (FX32_SHIFT+1)));
        
    pSelfTask->pos.x += (pSelfTask->velocity.x >> 3);   // Smoke drifts in wind
    
    spriteSmoke.basicParams.simpleParams.pos.y     = (s16)(-gBgVScroll + (pSelfTask->pos.y >> FX32_SHIFT) - (pSelfTask->size.y >> (FX32_SHIFT + 1)));   // Match exactly to the feet
    spriteSmoke.basicParams.simpleParams.size.x    = (s16)(pSelfTask->size.x >> FX32_SHIFT);
    spriteSmoke.basicParams.simpleParams.size.y    = (s16)(pSelfTask->size.y >> FX32_SHIFT);
    spriteSmoke.basicParams.simpleParams.rotZ      = 0;
    spriteSmoke.basicParams.simpleParams.priority  = DISPLAY_PRIORITY_SMOKE;
    spriteSmoke.basicParams.simpleParams.alpha     = (u8)pSelfTask->alpha;

    // Do Draw
    NNS_G2dDrawSpriteExtended( &spriteSmoke );

    pSelfTask->animSpeed -= FX32_ONE>>1;    // Use the disappearance speed adjustment for animSpeed
    if (pSelfTask->animSpeed < 0)
    {
        pSelfTask->animSpeed = FX32_ONE;

        pSelfTask->size.x += FX32_ONE;
        pSelfTask->size.y += FX32_ONE;

        if (pSelfTask->alpha-- == 0)
        {
            pSelfTask->common.reqReleaseFlag = TRUE;
        }
    }
}
