/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     stage00_schedule.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include "utility.h"
#include "task_priority.h"
#include "yoshi.h"
#include "enemy.h"
#include "emitter.h"
#include "schedule.h"

// Declaration of internal functions
static void SetEvent(u32 hit);

const EventHappen eventArray[] =
{
    // Region,         Added task,             Priority,               Appearance position difference,   Size,                             H Speed,          V Speed
    { FX32_ONE * 001,  HeihoRedBirth,          TASK_PRIORITY_ENEMY,    {FX32_ONE * 300, -FX32_ONE * 80}, {FX32_ONE * 2, FX32_ONE * 2}, -FX32_HALF,     0        },
    { FX32_ONE * 100,  HeihoRedBirth,          TASK_PRIORITY_ENEMY,    {FX32_ONE * 300, -FX32_ONE * 80}, {FX32_ONE,     FX32_ONE    }, -FX32_HALF,     FX32_ONE },
    { FX32_ONE * 300,  HeihoRedBirth,          TASK_PRIORITY_ENEMY,    {FX32_ONE * 300, -FX32_ONE * 80}, {FX32_ONE,     FX32_ONE    }, -FX32_HALF,     FX32_ONE },
    { FX32_ONE * 400,  HeihoRedBirth,          TASK_PRIORITY_ENEMY,    {FX32_ONE * 300, -FX32_ONE * 80}, {FX32_ONE * 1, FX32_ONE * 1}, -FX32_HALF,     FX32_ONE },
    { FX32_ONE * 500,  HeihoRedBirth,          TASK_PRIORITY_ENEMY,    {FX32_ONE * 300, -FX32_ONE * 80}, {FX32_ONE,     FX32_ONE    }, -FX32_HALF,     FX32_ONE },
    { FX32_ONE * 600,  HeihoRedBirth,          TASK_PRIORITY_ENEMY,    {FX32_ONE * 300, -FX32_ONE * 80}, {FX32_ONE * 1, FX32_ONE * 1}, -FX32_HALF,     FX32_ONE },
    { FX32_ONE * 999,  HeihoRedEmitter_Init,   TASK_PRIORITY_ENEMY,    {             0,              0}, {           0,            0},         0,      0        },
    { FX32_ONE * 1300, HeihoRedBirth,          TASK_PRIORITY_ENEMY,    {FX32_ONE * 300, -FX32_ONE * 80}, {FX32_ONE,     FX32_ONE    }, -FX32_HALF,     FX32_ONE },
    { FX32_ONE * 1400, HeihoRedBirth,          TASK_PRIORITY_ENEMY,    {FX32_ONE * 300, -FX32_ONE * 80}, {FX32_ONE * 1, FX32_ONE * 1}, -FX32_HALF,     FX32_ONE },
    { FX32_ONE * 1500, HeihoRedBirth,          TASK_PRIORITY_ENEMY,    {FX32_ONE * 300, -FX32_ONE * 80}, {FX32_ONE * 1, FX32_ONE * 1}, -FX32_HALF,     FX32_ONE },
    { FX32_ONE * 1600, HeihoRedBirth,          TASK_PRIORITY_ENEMY,    {FX32_ONE * 300, -FX32_ONE * 80}, {FX32_ONE,     FX32_ONE    }, -FX32_HALF,     FX32_ONE },
    { FX32_ONE * 1700, Killer_Init,  TASK_PRIORITY_ENEMY_NOTRENDER,    {FX32_ONE * 300, -FX32_ONE * 50}, {FX32_ONE,     FX32_ONE    }, -FX32_ONE,      0        },
    { FX32_ONE * 1800, HeihoRedBirth,          TASK_PRIORITY_ENEMY,    {FX32_ONE * 300, -FX32_ONE * 80}, {FX32_ONE / 2, FX32_ONE / 2}, -FX32_HALF / 2, FX32_ONE },
    { FX32_ONE * 1801, HeihoRedBirth,          TASK_PRIORITY_ENEMY,    {FX32_ONE * 315, -FX32_ONE * 80}, {FX32_ONE / 2, FX32_ONE / 2}, -FX32_HALF / 2, FX32_ONE },
    { FX32_ONE * 1802, HeihoRedBirth,          TASK_PRIORITY_ENEMY,    {FX32_ONE * 330, -FX32_ONE * 80}, {FX32_ONE / 2, FX32_ONE / 2}, -FX32_HALF / 2, FX32_ONE },
    { FX32_ONE * 1803, HeihoRedBirth,          TASK_PRIORITY_ENEMY,    {FX32_ONE * 345, -FX32_ONE * 80}, {FX32_ONE / 2, FX32_ONE / 2}, -FX32_HALF / 2, FX32_ONE },
    { FX32_ONE * 1804, HeihoRedBirth,          TASK_PRIORITY_ENEMY,    {FX32_ONE * 360, -FX32_ONE * 80}, {FX32_ONE / 2, FX32_ONE / 2}, -FX32_HALF / 2, FX32_ONE },
    { FX32_ONE * 1805, HeihoRedBirth,          TASK_PRIORITY_ENEMY,    {FX32_ONE * 375, -FX32_ONE * 80}, {FX32_ONE / 2, FX32_ONE / 2}, -FX32_HALF / 2, FX32_ONE },
    { FX32_ONE * 2000, HeihoRedBirth,          TASK_PRIORITY_ENEMY,    {FX32_ONE * 300, -FX32_ONE * 80}, {FX32_ONE,     FX32_ONE    }, -FX32_HALF,     FX32_ONE }
};

static BOOL eventFlags[sizeof(eventArray)/sizeof(eventArray[0])];   /* Event occurence flag */

/*---------------------------------------------------------------------------*
  Name:         Stage00_Schedule

  Description:  Generate an event based on Yoshi's X coordinate.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void Stage00_Schedule(void)
{
    Task* pSelfTask = TaskCtrl_GetCurrentTask();
    
    u32 i;
    u32 num = sizeof(eventArray)/sizeof(eventArray[0]);
    fx32 yoshi_x  = FX_Mod(gYoshiPos.x, FX32_ONE * STAGE_LENGTH);
    s32 hit = -1;

    if (yoshi_x < 0)
    {
        yoshi_x += FX32_ONE * STAGE_LENGTH;     // corresponds to the negative coordinates
    }

    for (i=0;i<num;i++)
    {
        fx32 distance;

        if (yoshi_x < eventArray[i].location + EVENT_HAPPEN_RANGE)
        {
            if (yoshi_x > eventArray[i].location)
            {
                SetEvent(i);
            }
        }

        distance = FX_ABS(yoshi_x - eventArray[i].location);
        if (distance > FX32_ONE * (STAGE_LENGTH>>1))        // Set the maximum distance value to 1023 so that 2048 is one cycle
        {
            distance = FX32_ONE * STAGE_LENGTH - distance;  // If the distance exceeds 1024, flip based on 2048 (2047->1)
        }                                                   //                                                   (1025->1023)
        if (distance > FX32_ONE * 1000)
        {
            eventFlags[i] = FALSE;
        }
    }       
}

/*---------------------------------------------------------------------------*
  Name:         Stage00_Schedule

  Description:  Generates an event task.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

static inline void SetEvent(u32 hit)
{
    Task* pSelfTask = TaskCtrl_GetCurrentTask();    
    EnemyTask* temp;
    fx32 velocity_h;
    
    if (hit != -1 && eventFlags[hit] == FALSE) 
    {
        temp = (EnemyTask *)TaskCtrl_SetTask(eventArray[hit].func, eventArray[hit].priority);
        velocity_h = eventArray[hit].velocity_h;    
        temp->velocity.x          = velocity_h;
        temp->velocity.y = eventArray[hit].velocity_v;
        temp->pos.x = gYoshiPos.x + eventArray[hit].pos_diff.x;
        temp->pos.y = gYoshiPos.y + eventArray[hit].pos_diff.y;
        temp->size.x = eventArray[hit].size.x;
        temp->size.y = eventArray[hit].size.y;
        eventFlags[hit] = TRUE;
    }
}

/*---------------------------------------------------------------------------*
  Name:         Stage00_Schedule_Init

  Description:  Initializes the event flag.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void Stage00_ClearEventFlags(void)
{
    MI_CpuClear8( eventFlags, sizeof(eventFlags));
}


