/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     star.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include <nnsys/g2d.h>
#include "read_key.h"
#include "effect.h"
#include "renderer.h"

/*---------------------------------------------------------------------------*
  Name:         Star

  Description:  Displays a star (the damage effect when an enemy is stepped on).
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void Star(void)
{
    EffectTask* pSelfTask  = (EffectTask *)TaskCtrl_GetCurrentTask();
    static u16   rotate  = 0;           // Angle of rotation
    NNSG2dFVec2  scale;                 // Scale
    NNSG2dFVec2  pos;                   // Cell render position
    
    scale.x = pSelfTask->size.x;
    scale.y = pSelfTask->size.y;

    pSelfTask->pos.x += pSelfTask->velocity.x;
    pSelfTask->pos.y += pSelfTask->velocity.y;
    pSelfTask->velocity.x *= 0.8;
    pSelfTask->velocity.y *= 0.8;
    
    // Display X cordinate calculation
    pos.x = FX32_SCREEN_CENTER_X + pSelfTask->pos.x - gYoshiPos.x;
        
    // Display Y coordinate calculation
    pos.y = pSelfTask->pos.y - FX32_ONE * gBgVScroll;

    // Material configuration
    MaterialSetup();
    
    // Render
    //
    // Render the cell using the Renderer module.
    //
        
    // Configure the image data the renderer references and the palette data
    NNS_G2dSetRendererImageProxy( &render3D, &objDataStar.imageProxy, &objDataStar.paletteProxy );
    NNS_G2dPushMtx();
        NNS_G2dTranslate( pos.x, pos.y, FX32_ONE * 10 );
        NNS_G2dRotZ( FX_SinIdx( rotate ), FX_CosIdx( rotate ) );
        NNS_G2dScale( scale.x, scale.y, FX32_ONE );
        NNS_G2dDrawCellAnimation( pSelfTask->cellAnim );
    NNS_G2dPopMtx();

    // Erase the task when the animation completes.
    // It is probably OK to use an animation callback to do so.
    {
        NNSG2dAnimController* pAnimCtrl = &pSelfTask->cellAnim->animCtrl;
        u32 num = pAnimCtrl->pAnimSequence->numFrames;          
        if (pAnimCtrl->pCurrent == &pAnimCtrl->pAnimSequence->pAnmFrameArray[num-1])
        {
            pSelfTask->common.reqReleaseFlag = TRUE;
        }
    }

    // Tick animation
    NNS_G2dTickCellAnimation( pSelfTask->cellAnim, FX32_ONE );
}
