/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     star_birth.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/
#include <nitro.h>
#include <nnsys/g2d.h>

#include "utility.h"
#include "effect.h"
#include "vram_map.h"

// Declaration of functions
static void StarFree(EffectTask* task);

/*---------------------------------------------------------------------------*
  Name:         StarBirth

  Description:  Execute when generating the Heiho task.
                Changes the task to [Star_Init]
                after initializing the animation.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void StarBirth(void)
{
    EffectTask* pSelfTask = (EffectTask *)TaskCtrl_GetCurrentTask();

    pSelfTask->animSpeed = FX32_ONE;
    pSelfTask->direction = (pSelfTask->velocity.x > 0) ? RIGHT : LEFT ;     
    pSelfTask->common.releaseFunc = StarFree;

    // Initializes the cell animation entity
    {                    
        pSelfTask->cellAnim = UT_GetCellAnimation();    // Get an empty NNSG2dCellAnimation
                                                        // Deallocate at the time the task is released
        SDK_NULL_ASSERT( pSelfTask->cellAnim );
        SDK_ASSERT( objDataStar.pAnimBank->numSequences != 0 );
        SDK_NULL_ASSERT( &objDataStar.pAnimBank->pSequenceArrayHead[0] );
        NNS_G2dInitCellAnimation( 
                    pSelfTask->cellAnim,                            
                    &objDataStar.pAnimBank->pSequenceArrayHead[0],  
                    objDataStar.pCellBank );
    }
    
    pSelfTask->common.func = Star_Init;        // Change task to [Star_Init]
}

/*---------------------------------------------------------------------------*
  Name:         StarFree

  Description:  Deallocates the region allocated by StarBirth.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

static void StarFree(EffectTask* task)
{
    // Deallocates the cell animation
    UT_ReleaseCellAnimation(task->cellAnim);
}

