/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     title.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include <nnsys/g2d.h>
#include "vram_map.h"
#include "effect.h"
#include "read_key.h"
#include "renderer.h"

// Internal function declaration 
static void TitleMove(EffectTask* task);

/*---------------------------------------------------------------------------*
  Name:         Title

  Description:  Displays the title.

  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void Title(void)
{
    EffectTask* pSelfTask = (EffectTask *)TaskCtrl_GetCurrentTask();
    
    // Title move process
    TitleMove(pSelfTask);

    // Material setting
    MaterialSetup();

    // Set the image data and palette data referenced by the renderer.
    NNS_G2dSetRendererImageProxy( &render2D, &objDataTitle.imageProxy, &objDataTitle.paletteProxy );  

    // Draw
    NNS_G2dPushMtx();
        NNS_G2dTranslate( FX32_SCREEN_CENTER_X, pSelfTask->pos.y, 0 );
        NNS_G2dDrawCell(objDataTitle.pCellBank->pCellDataArrayHead);
    NNS_G2dPopMtx();
}

/*---------------------------------------------------------------------------*
  Name:         TitleMove

  Description:  Executes the title move process.

  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

static void TitleMove(EffectTask* task)
{
    task->pos.y += task->velocity.y;
    
    if (task->pos.y > TITLE_DOWN_POSITION)
    {
        task->pos.y = TITLE_DOWN_POSITION;
    }
    else if (task->pos.y < TITLE_UP_POSITION)
    {
        task->pos.y = TITLE_UP_POSITION;    
    }
}


