/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     yoshi_airwalk.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include <nnsys/g2d.h>  
#include "read_key.h"
#include "yoshi.h"

// Internal function declaration 
static void Accelerate(void);

/*---------------------------------------------------------------------------*
  Name:         YoshiAirWalk

  Description:  Displays Yoshi in upward state.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void YoshiAirWalk(void)
{
    YoshiTask* pSelfTask = (YoshiTask *)TaskCtrl_GetCurrentTask();

    // Accelerated motion 
    Accelerate();
    
    // Move and determine the hit to the landscape
    MoveX_WithGroundCheckYoshi(pSelfTask); 
    MoveY_WithGroundCheckYoshi(pSelfTask); 

    if (pSelfTask->attackSuccess == ATTACK_STEP_ON) // Stepped on the enemy
    {
        pSelfTask->attackSuccess = ATTACK_NONE;
        pSelfTask->velocity.y = FX32_ONE * 5;
        pSelfTask->spirit = 60;                     // Recovering spirit
        pSelfTask->common.func = YoshiJumpUp_Init;
    }
    else if(!IS_PRESS(PAD_BUTTON_A))                // Air walk ends when A button is released
    {
        if (pSelfTask->velocity.y > 0)
        {
            pSelfTask->common.func = YoshiJumpUp_Init;
        }
        else
        {
            pSelfTask->common.func = YoshiJumpDown_Init;           
        }
    }

    // Update the animation
    NNS_G2dTickCellAnimation( pSelfTask->cellAnim, pSelfTask->animSpeed );

    // Draw
    DrawYoshi();
}

/*---------------------------------------------------------------------------*
  Name:         Accelerate

  Description:  Processes the acceleration movement.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

static void Accelerate(void)
{
    YoshiTask* pSelfTask = (YoshiTask *)TaskCtrl_GetCurrentTask();

    if(IS_PRESS(PAD_BUTTON_B))  // B-dash acceleration
    {
        if (IS_PRESS(PAD_KEY_RIGHT) && pSelfTask->velocity.x < FX32_ONE<<1)
        {
            pSelfTask->velocity.x += FX32_ONE * 0.02;           
        }
        else if (IS_PRESS(PAD_KEY_LEFT) && pSelfTask->velocity.x > FX32_ONE * -2)
        {
            pSelfTask->velocity.x -= FX32_ONE * 0.02;       
        }
    }
    else                        // Normal acceleration
    {
        if (IS_PRESS(PAD_KEY_RIGHT) && pSelfTask->velocity.x < FX32_ONE)
        {
            pSelfTask->velocity.x += FX32_ONE * 0.02;           
        }
        else if (IS_PRESS(PAD_KEY_LEFT) && pSelfTask->velocity.x > FX32_ONE * -1)
        {
            pSelfTask->velocity.x -= FX32_ONE * 0.02;       
        }   
    }

    // AirWalk is special
    if (pSelfTask->spirit > 0)
    {
        pSelfTask->spirit--;                        // Declining spirit
        pSelfTask->velocity.y += FX32_ONE * 0.3;    // ascending force (0.3) + gravity (-0.2) = + 0.1
        if (pSelfTask->velocity.y > FX32_ONE * 2)
        {
            pSelfTask->velocity.y = FX32_ONE * 2;
        }
    }
}

