/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     yoshi_airwalk_init.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include <nnsys/g2d.h>
#include "yoshi.h"

/*---------------------------------------------------------------------------*
  Name:         YoshiAirWalk_Init

  Description:  Executes the initialization process before executing "YoshiAirWalk."
                Changes the task to "YoshiAirWalk."
                Executes "YoshiAirWalk" directly.
  
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void YoshiAirWalk_Init(void)
{
    YoshiTask* pSelfTask = (YoshiTask *)TaskCtrl_GetCurrentTask();

    // Cell animation sequence setting   
    const NNSG2dAnimSequence* pSeq;
    pSeq = NNS_G2dGetAnimSequenceByIdx( objDataYoshi.pAnimBank, YOSHI_ANIM_AIR_WALK );
    NNS_G2dSetCellAnimationSequence( pSelfTask->cellAnim, pSeq );

    // Cell animation rewind
    NNS_G2dSetCellAnimationCurrentFrame(pSelfTask->cellAnim, 0);

    // Cell animation playback
    NNS_G2dStartAnimCtrl(NNS_G2dGetCellAnimationAnimCtrl(pSelfTask->cellAnim));

    pSelfTask->animSpeed = FX32_ONE * 2;
    pSelfTask->common.func = YoshiAirWalk;      // Change the task to "YoshiAirWalk"
    YoshiAirWalk();                             // Execute "YoshiAirWalk"
}

