/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     yoshi_birth.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/
 
#include <nitro.h>
#include <nnsys/g2d.h>
#include "utility.h"
#include "vram_map.h"
#include "yoshi.h"

/*---------------------------------------------------------------------------*
  Name:         YoshiBirth

  Description:  Execute when generating Yoshi's task.
                After the animation was initialized, 
                the task is changed to "YoshiStay_Init."
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/
 
void YoshiBirth(void)
{
    YoshiTask* pSelfTask = (YoshiTask *)TaskCtrl_GetCurrentTask();

    // Set the coordinates of Yoshi to the global variable
    gYoshiPos.x = pSelfTask->pos.x;
    gYoshiPos.y = pSelfTask->pos.y;

    // Obtain a new cell transfer state management object.
    // When the object is no longer needed, 
    // release it with NNS_G2dFreeCellTransferStateHandle( handle ).  
    pSelfTask->cellTransManHandle = NNS_G2dGetNewCellTransferStateHandle();
    SDK_ASSERT( pSelfTask->cellTransManHandle != NNS_G2D_INVALID_CELL_TRANSFER_STATE_HANDLE );


    // Initialize the cell animation entity
    {
        pSelfTask->cellAnim = UT_GetCellAnimation();

        SDK_NULL_ASSERT( pSelfTask->cellAnim );
        SDK_ASSERT( (objDataYoshi.pAnimBank)->numSequences != 0 );
        SDK_NULL_ASSERT( NNS_G2dGetAnimSequenceByIdx(objDataYoshi.pAnimBank, 0) );
        SDK_ASSERT( NNS_G2dCellDataBankHasVramTransferData(objDataYoshi.pCellBank) );

        NNS_G2dInitCellAnimationVramTransfered(
            pSelfTask->cellAnim,
            NNS_G2dGetAnimSequenceByIdx(objDataYoshi.pAnimBank, 0),
            objDataYoshi.pCellBank,

            pSelfTask->cellTransManHandle,      // Manage the VRAM transfer of this cell animation
                                                // Handle for the cell transfer state management object
                                                // The following three are passed to the callback function of (1) as dstAddr
                                                // Normally, specify the same value as the one specified for ImageProxy
            VRAM_MAP_TEX_YOSHI,                 // Texture transfer destination offset
            NULL,                               // Main screen character transfer destination offset
            NULL,                               // Sub screen character transfer destination offset
                                                // One of the following two can be NULL
            NULL,                               // Character data
            objDataYoshi.pCharData->pRawData,   // Texture data
            objDataYoshi.pCharData->szByte      // Size of the texture data or character data
        );
    }

    pSelfTask->common.func = YoshiStay_Init;    // Change the task to "YoshiStay_Init"
    YoshiStay_Init();                           // Execute "YoshiStay_Init"
}

/*---------------------------------------------------------------------------*
  Name:         YoshiFree

  Description:  Releases the region that was allocated with YoshiBirth.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void YoshiFree(YoshiTask* task)
{
    // Release the cell transfer state management object
    NNS_G2dFreeCellTransferStateHandle(task->cellTransManHandle);
    
    // Release the cell animation
    UT_ReleaseCellAnimation(task->cellAnim);
}



