/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     yoshi_brake.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include <nnsys/g2d.h>
#include "task_priority.h"
#include "read_key.h"
#include "yoshi.h"
#include "effect.h"

/*---------------------------------------------------------------------------*
  Name:         YoshiBrake

  Description:  Displays Yoshi in breaking state.
                Changes the task to "YoshiStay_Init" at speed 0.
                Immediately changes the task to "YoshiWalk_Init" by entering the direction of movement.
                       
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void YoshiBrake(void)
{
    YoshiTask* pSelfTask = (YoshiTask *)TaskCtrl_GetCurrentTask();

    // Move and determine the hit to the landscape
    MoveX_WithGroundCheckYoshi(pSelfTask); 
    
    if (pSelfTask->velocity.x > FX32_ONE)
    {
        pSelfTask->velocity.x -= FX32_ONE * 0.05;// Break
    }else{
        pSelfTask->velocity.x += FX32_ONE * 0.05;
    }
                
    // Draw
    DrawYoshi();

    if(IS_TRIG(PAD_BUTTON_A))                   // Jump
    {
        pSelfTask->velocity.y = FX32_ONE * 5;
        pSelfTask->common.func = YoshiJumpUp_Init;
    }
    else if (IS_PRESS(PAD_KEY_RIGHT) && pSelfTask->direction == RIGHT)  
    {
        pSelfTask->common.func = YoshiWalk_Init;       // Change the task to "YOSHI_WALK_INIT"
    }
    else if (IS_PRESS(PAD_KEY_LEFT) && pSelfTask->direction == LEFT)
    {
        pSelfTask->common.func = YoshiWalk_Init;       // Change the task to "YOSHI_WALK_INIT"              
    }
    else if (pSelfTask->velocity.x <= FX32_ONE && pSelfTask->velocity.x >= FX32_ONE * -1)
    {
        pSelfTask->velocity.x  = 0;                    // Stops if the velocity is less than a certain value
        pSelfTask->common.func = YoshiStay_Init;
    }
    
    // Generates the clouds of dust task to coordinate with the break
    {
        EffectTask* effect;
        effect = (EffectTask *)TaskCtrl_SetTask(Smoke_Init, TASK_PRIORITY_EFFECT_NOTRENDER_ALPHA);
        effect->pos = pSelfTask->pos;           // Sets the location of clouds of dust
        effect->velocity = pSelfTask->velocity; // Sets the velocity of clouds of dust
    }
}

