/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     yoshi_front_turn.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include <nnsys/g2d.h>
#include "read_key.h"
#include "yoshi.h"

/*---------------------------------------------------------------------------*
  Name:         YoshiFrontTurn

  Description:  Displays Yoshi in turning state.
                Changes the task to "YoshiStay_Init" at the end of the animation.

  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void YoshiFrontTurn(void)
{
    YoshiTask* pSelfTask = (YoshiTask *)TaskCtrl_GetCurrentTask();

    // Update animation
    NNS_G2dTickCellAnimation( pSelfTask->cellAnim, pSelfTask->animSpeed );

    // Draw
    DrawYoshi();

    // Changes into the next state at the end of the animation.
    // The end of animation determination can also be done with callback.
    {
        NNSG2dAnimController* pAnimCtrl = &pSelfTask->cellAnim->animCtrl;
        u32 num = pAnimCtrl->pAnimSequence->numFrames;          
        if (pAnimCtrl->pCurrent == &pAnimCtrl->pAnimSequence->pAnmFrameArray[num - 1])
        {
            pSelfTask->common.func = YoshiStay_Init;   // Change the task to "YOSHI_STAY_INIT"
        }
    }

    // Jump
    if(IS_TRIG(PAD_BUTTON_A))
    {
        pSelfTask->velocity.y = FX32_ONE * 5;
        pSelfTask->common.func = YoshiJumpUp_Init;
    }
}

