/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     yoshi_jump_up.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include <nnsys/g2d.h>  
#include "read_key.h"
#include "yoshi.h"

// Internal function declaration 
static void Accelerate(void);

/*---------------------------------------------------------------------------*
  Name:         YoshiJumpUp

  Description:  Displays Yoshi in upward state.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void YoshiJumpUp(void)
{
    YoshiTask* pSelfTask = (YoshiTask *)TaskCtrl_GetCurrentTask();

    // Accelerated motion  
    Accelerate();

    // Move and determine the hit to the landscape
    MoveX_WithGroundCheckYoshi(pSelfTask); 
    MoveY_WithGroundCheckYoshi(pSelfTask); 
    
    // Update the animation
    NNS_G2dTickCellAnimation( pSelfTask->cellAnim, pSelfTask->animSpeed );

    // Draw
    DrawYoshi();
    

    if(!IS_PRESS(PAD_BUTTON_A)) // Changes the height of the jump depending on the length of A button being pressed.
    {
        pSelfTask->velocity.y -= FX32_ONE * 0.4;
    }
}

/*---------------------------------------------------------------------------*
  Name:         Accelerate

  Description:  Processes the acceleration movement.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

static void Accelerate(void)
{
    YoshiTask* pSelfTask = (YoshiTask *)TaskCtrl_GetCurrentTask();
    
    if(IS_PRESS(PAD_BUTTON_B))  // B-dash acceleration
    {
        if (IS_PRESS(PAD_KEY_RIGHT) && pSelfTask->velocity.x < FX32_ONE<<1)
        {
            pSelfTask->velocity.x += FX32_ONE * 0.02;           
        }
        else if (IS_PRESS(PAD_KEY_LEFT) && pSelfTask->velocity.x > FX32_ONE * -2)
        {
            pSelfTask->velocity.x -= FX32_ONE * 0.02;       
        }
    }
    else                        // Normal acceleration
    {
        if (IS_PRESS(PAD_KEY_RIGHT) && pSelfTask->velocity.x < FX32_ONE)
        {
            pSelfTask->velocity.x += FX32_ONE * 0.02;           
        }
        else if (IS_PRESS(PAD_KEY_LEFT) && pSelfTask->velocity.x > FX32_ONE * -1)
        {
            pSelfTask->velocity.x -= FX32_ONE * 0.02;       
        }   
    }
}
