/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     yoshi_jump_up_init.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nnsys/g2d/g2d_Load.h>
#include "yoshi.h"

/*---------------------------------------------------------------------------*
  Name:         YoshiJumpUp_Init

  Description:  Executes the initialization process before executing "YoshiJumpUp."
                Changes the task to "YoshiJumpUp."
                Executes "YoshiJumpUp" directly.
                
                Vertical velocity vertical_velocity needs to be set 
                before the task is changed to YoshiJumpUp_Init.
 
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void YoshiJumpUp_Init(void)
{
    YoshiTask* pSelfTask = (YoshiTask *)TaskCtrl_GetCurrentTask();
    const NNSG2dAnimSequence* pSeq;

    // Cell animation sequence setting 
    pSeq = NNS_G2dGetAnimSequenceByIdx( objDataYoshi.pAnimBank, YOSHI_ANIM_JUMP_UP );
    NNS_G2dSetCellAnimationSequence( pSelfTask->cellAnim, pSeq );

    // Cell animation rewind
    NNS_G2dSetCellAnimationCurrentFrame(pSelfTask->cellAnim, 0);

    // Cell animation playback
    NNS_G2dStartAnimCtrl(NNS_G2dGetCellAnimationAnimCtrl(pSelfTask->cellAnim));

    pSelfTask->animSpeed = FX32_ONE;    
    pSelfTask->common.func = YoshiJumpUp;   // Change the task to "YoshiJumpUp"
    YoshiJumpUp();                          // Execute "YoshiJumpUp"
}

