/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     yoshi_stay.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include <nnsys/g2d.h>
#include "read_key.h"
#include "yoshi.h"

/*---------------------------------------------------------------------------*
  Name:         YoshiStay

  Description:  Displays Yoshi in stopping state.
                Changes the task according to the key input.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void YoshiStay(void)
{
    YoshiTask* pSelfTask = (YoshiTask *)TaskCtrl_GetCurrentTask();

    // Update the animation
    NNS_G2dTickCellAnimation( pSelfTask->cellAnim, pSelfTask->animSpeed );

    // Draw            
    DrawYoshi();


    if(IS_TRIG(PAD_BUTTON_A))
    {
        pSelfTask->velocity.y = FX32_ONE * 5;
        pSelfTask->common.func = YoshiJumpUp_Init;             // Change the task to "YoshiJumpUp_Init"
    }
    else if (pSelfTask->velocity.x != 0)                       // When jumped and landed
    {
        pSelfTask->common.func = YoshiBrake_Init;              // Change the task to "YoshiBrake_Init"
    }
    else if (IS_PRESS(PAD_KEY_RIGHT ))
    {
        if (pSelfTask->direction == LEFT)
        {
            pSelfTask->direction = RIGHT;
            pSelfTask->common.func = YoshiFrontTurn_Init;      // Change the task to "YoshiFrontTurn_Init"
        }else{
            pSelfTask->common.func = YoshiWalk_Init;           // Change the task to "YoshiWalk_Init"
        }
    }
    else if (IS_PRESS(PAD_KEY_LEFT))
    {
        if (pSelfTask->direction == RIGHT)
        {
            pSelfTask->direction = LEFT;
            pSelfTask->common.func = YoshiFrontTurn_Init;      // Change the task to "YoshiFrontTurn_Init"
        }else{
            pSelfTask->common.func = YoshiWalk_Init;           // Change the task to "YoshiWalk_Init"             
        }
    }       
}
