/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     yoshi_stay_init.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include <nnsys/g2d.h>
#include "yoshi.h"

/*---------------------------------------------------------------------------*
  Name:         YoshiStay_Init

  Description:  Executes the initialization process before executing "YoshiStay."
                Changes the task to "YoshiStay."
                Executes "YoshiStay" directly.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void YoshiStay_Init(void)
{
    YoshiTask* pSelfTask = (YoshiTask *)TaskCtrl_GetCurrentTask();
    const NNSG2dAnimSequence* pSeq;
    
    // Cell animation sequence setting 
    pSeq = NNS_G2dGetAnimSequenceByIdx( objDataYoshi.pAnimBank, YOSHI_ANIM_STAY );
    NNS_G2dSetCellAnimationSequence( pSelfTask->cellAnim, pSeq );

    // Cell animation rewind
    NNS_G2dSetCellAnimationCurrentFrame(pSelfTask->cellAnim, 0);

    // Cell animation playback
    NNS_G2dStartAnimCtrl(NNS_G2dGetCellAnimationAnimCtrl(pSelfTask->cellAnim));

    pSelfTask->animSpeed = FX32_ONE;
    pSelfTask->velocity.y = 0;
    pSelfTask->size.x = FX32_ONE;
    pSelfTask->size.y = FX32_ONE;
    pSelfTask->spirit = 60;             // Recovering spirit
    pSelfTask->common.func = YoshiStay; // Change the task to "YoshiStay"
    YoshiStay();                        // Execute "YoshiStay"
}

