/*---------------------------------------------------------------------------*
  Project:  G2D Program Sample
  File:     yoshi_walk.c

  Copyright 2004 Nintendo.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  $Log: $
  $NoKeywords: $
 *---------------------------------------------------------------------------*/

#include <nitro.h>
#include <nnsys/g2d.h>
#include "task_priority.h"
#include "read_key.h"
#include "yoshi.h"
#include "effect.h"

// Internal function definition
static void Accelerate(void);

/*---------------------------------------------------------------------------*
  Name:         YoshiWalk

  Description:  Displays Yoshi in walking state.
                Changes the task to "YoshiJumpUp_Init" with A button input.
                Changes the task to "YoshiStay_Init" at speed 0.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

void YoshiWalk(void)
{
    YoshiTask* pSelfTask = (YoshiTask *)TaskCtrl_GetCurrentTask();

    // Accelerated motion  
    Accelerate();

    // Move and determine the hit to the landscape
    MoveX_WithGroundCheckYoshi(pSelfTask); 

    // Update the animation
    NNS_G2dTickCellAnimation( pSelfTask->cellAnim, pSelfTask->animSpeed );

    // Draw
    DrawYoshi();

    if(IS_TRIG(PAD_BUTTON_A))
    {
        pSelfTask->velocity.y = FX32_ONE * 5;
        pSelfTask->common.func = YoshiJumpUp_Init;             // Change the task to "YoshiJumpUp_Init"
    }
    else if (IS_PRESS(PAD_KEY_RIGHT ))
    {
        if (pSelfTask->direction == LEFT)
        {
            if (pSelfTask->velocity.x >= FX32_ONE * -1)
            {
                pSelfTask->direction = RIGHT;
                pSelfTask->common.func = YoshiFrontTurn_Init;  // Change the task to "YoshiFrontTurn_Init"
            }else{
                pSelfTask->common.func = YoshiBrake_Init;      // Change the task to "YoshiBrake_Init"
            }
        }
    }            
    else if (IS_PRESS(PAD_KEY_LEFT))
    {
        if (pSelfTask->direction == RIGHT)
        {
            if (pSelfTask->velocity.x <= FX32_ONE)
            {
                pSelfTask->direction = LEFT;
                pSelfTask->common.func = YoshiFrontTurn_Init;  // Change the task to "YoshiFrontTurn_Init"
            }else{
                pSelfTask->common.func = YoshiBrake_Init;      // Change the task to "YoshiBrake_Init"
            }
        }
    }
    else
    {
        if (pSelfTask->velocity.x > FX32_ONE || pSelfTask->velocity.x < FX32_ONE * -1)
        {
            pSelfTask->common.func = YoshiBrake_Init;          // Change the task to "YoshiBrake_Init"          
        }else{
            pSelfTask->velocity.x  = 0;
            pSelfTask->common.func = YoshiStay_Init;           // Change the task to "YoshiStay_Init"
        }
    }

    if(IS_PRESS(PAD_BUTTON_B))
    {
        NNSG2dAnimController* pAnimCtrl = &pSelfTask->cellAnim->animCtrl;
        u32 num = pAnimCtrl->pAnimSequence->numFrames;          
        if (pAnimCtrl->pCurrent == &pAnimCtrl->pAnimSequence->pAnmFrameArray[1])
        {
            // Generates the clouds of dust task
            EffectTask* effect;
            effect = (EffectTask *)TaskCtrl_SetTask(Smoke_Init, TASK_PRIORITY_EFFECT_NOTRENDER_ALPHA);
            effect->pos = pSelfTask->pos;           // Sets the location of clouds of dust
            effect->velocity = pSelfTask->velocity; // Sets the velocity of clouds of dust
        }
    }    
}

/*---------------------------------------------------------------------------*
  Name:         Accelerate

  Description:  Processes the acceleration movement.
                        
  Arguments:    None
                
  Returns:      None
 *---------------------------------------------------------------------------*/

static void Accelerate(void)
{
    YoshiTask* pSelfTask = (YoshiTask *)TaskCtrl_GetCurrentTask();
    
    if(IS_PRESS(PAD_BUTTON_B))  // B-dash walk
    {
        if (pSelfTask->direction == RIGHT && pSelfTask->velocity.x < FX32_ONE<<1)   // When b-dash, the maximum velocity 2
        {
            pSelfTask->velocity.x += FX32_ONE * 0.02;   
        }
        else if (pSelfTask->velocity.x > FX32_ONE * -2)
        {
            pSelfTask->velocity.x -= FX32_ONE * 0.02;
        }
        
        if (pSelfTask->animSpeed < FX32_ONE<<1)
        {
            pSelfTask->animSpeed += FX32_ONE * 0.02;
        }       
    }else{                      // Normal walk
        if (pSelfTask->direction == RIGHT && pSelfTask->velocity.x > FX32_ONE)  // When normal walk, the maximum velocity 1
        {
                pSelfTask->velocity.x -= FX32_ONE * 0.02;                       // Slow down if exceeding the maximum velocity
        }
        else if (pSelfTask->velocity.x < FX32_ONE * -1)
        {
                pSelfTask->velocity.x += FX32_ONE * 0.02;                       // Slow down if exceeding the maximum velocity
        }
        
        if (pSelfTask->animSpeed > FX32_ONE)
        {
            pSelfTask->animSpeed -= FX32_ONE * 0.02;
        }       
    }   
}


